/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

(function() {
    /**
     * Shows the orientation type if the screen
     * @private
     */
    function showOrientation() {
        var orientationValue = document.getElementById("orientation");

        // Change the text to show the current orientation type
        if (screen.orientation.type === undefined) {
            orientationValue.innerHTML = screen.orientation;
        } else {
            orientationValue.innerHTML = screen.orientation.type;
        }
    }

    /**
     * Handles events for hardware key
     * @public
     * @param {Object} event - the object for click event
     */
    function keyEventHandler(event) {
        if (event.keyName === "back") {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (ignore) {

            }
        }
    }

    /**
     * Initiates the application
     * @private
     */
    function init() {
        // Show the orientation type of the screen when the application starts
        showOrientation();

        // Show the orientation type of the screen when it is changed
        try {
            // Event listener for Tizen 2.3.1 and 2.4 platforms
            screen.addEventListener("orientationchange", showOrientation, false);
        } catch (ignore) {

        }

        try {
            // Event listener for platforms after Tizen 3.0
            screen.orientation.addEventListener("change", showOrientation);
        } catch (ignore) {

        }

        // Add event listeners for Tizen hardware key
        document.addEventListener("tizenhwkey", keyEventHandler);
    }

    // Call the initiation function when the application is loaded
    window.onload = init();
}());